# Econometrics extension for OpenBB Platform

This extension provides a set of econometrics tools.

## Installation

To install the extension, run the following command in this folder:

```bash
pip install openbb-econometrics
```

For development please check [Contribution Guidelines](https://github.com/OpenBB-finance/OpenBBTerminal/blob/feature/openbb-sdk-v4/openbb_platform/CONTRIBUTING.md).

Documentation available [here](https://docs.openbb.co/sdk).
